@@ -31,7 +31,7 @@ def find_table_end_horizontal(ex, sheet_name: str, index_col: int, lookup_str: s
 def read_table(fname, **kwargs):
     ex = read_excel_file(fname)
     pandas_args = {x: kwargs[x] for x in kwargs if x in pandas_excel_parse_args}
-    sh = ex.parse(**pandas_args);
+    sh = ex.parse(**pandas_args)
 
     if 'table_end' in kwargs:
         table_end = find_table_end_horizontal(ex, kwargs.get('sheet_name'), index_col=kwargs['table_end']['index_col'],
@@ -55,6 +55,6 @@ def read_long_format_table(fname, **kwargs):
     value_col = kwargs.get('value_col')
     sh['index'] = sh.apply(lambda x: '.'.join(['%s' for x in dimension_cols]) % tuple([x[y] for y in dimension_cols]),
                            1)
-    sh['date'] = sh.index
-    sh = sh.groupby(['date', 'index']).mean().unstack()[value_col]
+    sh['date_as_index'] = sh.index
+    sh = sh.groupby(['date_as_index', 'index']).mean().unstack()[value_col]
     return sh
