@@ -1,6 +1,4 @@
-from datetime import date
 import pandas as pd
-import pytest
 import os
 from excel_scraper import excel_scraper
 
